Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(487)

Unified Diff: net/spdy/spdy_buffer.h

Issue 1852423004: Implement SpdySerializedFrame move semantics. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/spdy/buffered_spdy_framer_unittest.cc ('k') | net/spdy/spdy_buffer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/spdy/spdy_buffer.h
diff --git a/net/spdy/spdy_buffer.h b/net/spdy/spdy_buffer.h
index 94ee97fe6d5ab40889084e73986b86e41d53b734..d12c89fcf830094d8c939b1063473b0cf57c58ad 100644
--- a/net/spdy/spdy_buffer.h
+++ b/net/spdy/spdy_buffer.h
@@ -17,7 +17,7 @@
namespace net {
class IOBuffer;
-class SpdyFrame;
+class SpdySerializedFrame;
// SpdyBuffer is a class to hold data read from or to be written to a
// SPDY connection. It is similar to a DrainableIOBuffer but is not
@@ -47,7 +47,7 @@ class NET_EXPORT_PRIVATE SpdyBuffer {
// Construct with the data in the given frame. Assumes that data is
// owned by |frame| or outlives it.
- explicit SpdyBuffer(scoped_ptr<SpdyFrame> frame);
+ explicit SpdyBuffer(scoped_ptr<SpdySerializedFrame> frame);
// Construct with a copy of the given raw data. |data| must be
// non-NULL and |size| must be non-zero.
@@ -86,9 +86,9 @@ class NET_EXPORT_PRIVATE SpdyBuffer {
private:
void ConsumeHelper(size_t consume_size, ConsumeSource consume_source);
// Ref-count the passed-in SpdyFrame to support the semantics of
// |GetIOBufferForRemainingData()|.
- typedef base::RefCountedData<scoped_ptr<SpdyFrame> > SharedFrame;
+ typedef base::RefCountedData<scoped_ptr<SpdySerializedFrame>> SharedFrame;
class SharedFrameIOBuffer;
« no previous file with comments | « net/spdy/buffered_spdy_framer_unittest.cc ('k') | net/spdy/spdy_buffer.cc » ('j') | no next file with comments »
@@ -86,9 +86,9 @@ class NET_EXPORT_PRIVATE SpdyBuffer {
private:
void ConsumeHelper(size_t consume_size, ConsumeSource consume_source);
- // Ref-count the passed-in SpdyFrame to support the semantics of
+ // Ref-count the passed-in SpdySerializedFrame to support the semantics of
// |GetIOBufferForRemainingData()|.

Powered by Google App Engine
This is Rietveld 408576698